# Instructions

#### This is our test project.
#### Please install this pacage
```
pip install functions-by-alextsiasto
```

#### You can also install older version
```
pip install functions-by-alextsiasto==VERSION_NUMBER
```